==> haskell-hashable-time-0.3-214-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hashable-time
version:              0.3
visibility:           public
id:                   hashable-time-0.3-5B5tKMnMSKOEti1SR6RX88
key:                  hashable-time-0.3-5B5tKMnMSKOEti1SR6RX88
license:              BSD-3-Clause
maintainer:           Alexey Karakulov <ankarakulov@gmail.com>
author:               Alexey Karakulov <ankarakulov@gmail.com>
synopsis:             Hashable instances for Data.Time
description:          Hashable instances for types in Data.Time
category:             Data
abi:                  93c7d2b68a849b537db8c2b317f6e1a8
exposed:              True
exposed-modules:      Data.Hashable.Time
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hashable-time
hs-libraries:         HShashable-time-0.3-5B5tKMnMSKOEti1SR6RX88
depends:
    base-4.18.2.1 time-compat-1.9.8-KXBZmSgVcbpGOqrx2hUfcV

haddock-interfaces:
    /usr/share/doc/haskell-hashable-time/html/hashable-time.haddock

haddock-html:         /usr/share/doc/haskell-hashable-time/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hashable-time-0.3-215-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hashable-time.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hashable-time
version:              0.3
visibility:           public
id:                   hashable-time-0.3-AJDKL3j4XsADPTOhZsVVt6
key:                  hashable-time-0.3-AJDKL3j4XsADPTOhZsVVt6
license:              BSD-3-Clause
maintainer:           Alexey Karakulov <ankarakulov@gmail.com>
author:               Alexey Karakulov <ankarakulov@gmail.com>
synopsis:             Hashable instances for Data.Time
description:          Hashable instances for types in Data.Time
category:             Data
abi:                  6652c11fb6e07b208a9a32b4f13e6adf
exposed:              True
exposed-modules:      Data.Hashable.Time
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hashable-time-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hashable-time
hs-libraries:         HShashable-time-0.3-AJDKL3j4XsADPTOhZsVVt6
depends:
    base-4.18.2.1 time-compat-1.9.8-ITy6Cf33IaSAWRM66COV33

haddock-interfaces:
    /usr/share/doc/haskell-hashable-time/html/hashable-time.haddock

haddock-html:         /usr/share/doc/haskell-hashable-time/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
